package ru.ulstu.admin.controller;

import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import ru.ulstu.admin.model.IndicatorForm;
import ru.ulstu.admin.service.AdminIndicatorService;
import ru.ulstu.indicator.model.Course;
import ru.ulstu.indicator.model.Indicator;
import ru.ulstu.model.UserRoleConstants;

@Controller
@RequestMapping("/admin")
@Secured({UserRoleConstants.ADMIN})
public class AdminIndicatorController {
    private final AdminIndicatorService adminIndicatorService;

    public AdminIndicatorController(AdminIndicatorService adminIndicatorService) {
        this.adminIndicatorService = adminIndicatorService;
    }

    @GetMapping("indicators")
    public String getListOfIndicators(Model model) {
        model.addAttribute("indicators", adminIndicatorService.getIndicators());
        return "admin/indicatorsList";
    }

    @GetMapping("/editIndicator/{indicatorId}")
    public String editIndicator(@PathVariable(value = "indicatorId") Integer id, Model model) {
        model.addAttribute("indicator",
                (id != null && id != 0)
                        ? adminIndicatorService.getIndicatorById(id)
                        : new Indicator());
        model.addAttribute("courses", Course.values());
        return "admin/editIndicator";
    }

    @PostMapping(value = "saveIndicator", params = "save")
    public String saveIndicator(IndicatorForm indicatorForm, Model model) {
        adminIndicatorService.saveIndicator(indicatorForm);
        return "redirect:/admin/indicators";
    }

    @PostMapping(value = "saveIndicator", params = "delete")
    public String deleteIndicator(IndicatorForm indicatorForm, Model model) {
        adminIndicatorService.deleteIndicator(indicatorForm);
        return "redirect:/admin/indicators";
    }
}
