package ru.ulstu.aspirant.service;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import ru.ulstu.admin.model.AspirantForm;
import ru.ulstu.aspirant.model.Aspirant;
import ru.ulstu.aspirant.repository.AspirantRepository;
import ru.ulstu.indicator.model.Course;
import ru.ulstu.indicator.model.Indicator;
import ru.ulstu.indicator.service.IndicatorService;
import ru.ulstu.user.UserUtils;

import java.util.List;

@Service
public class AspirantService {
    private final AspirantRepository aspirantRepository;
    private final IndicatorService indicatorService;

    public AspirantService(AspirantRepository aspirantRepository,
                           IndicatorService indicatorService) {
        this.aspirantRepository = aspirantRepository;
        this.indicatorService = indicatorService;
    }

    public List<Aspirant> getAspirants() {
        return aspirantRepository.findAll();
    }

    public Aspirant getAspirantById(Integer id) {
        return aspirantRepository.findById(id).orElseThrow(() -> new RuntimeException("Aspirant not found by id"));
    }

    public void save(Aspirant aspirant) {
        aspirantRepository.save(aspirant);
    }

    public void deleteAspirant(AspirantForm aspirantForm) {
        aspirantRepository.deleteById(aspirantForm.getId());
    }

    public Aspirant getAspirantByUser(String currentUserLogin) {
        //return aspirantRepository.getAspirantByLogin();
        //TODO: read aspirant
        return aspirantRepository.findAll().stream().findAny().orElse(new Aspirant("default", Course.FIRST));
    }

    public List<Indicator> getIndicatorsByCourse() {
        Aspirant aspirant = getAspirantByUser(UserUtils.getCurrentUserLogin());
        return indicatorService.getIndicatorsByCourse(aspirant.getCourse());
    }

    public Page<Indicator> getIndicatorsByCourse(Pageable pageable) {
        return indicatorService.getIndicatorsByCourse(pageable);
    }
}
